netapp_ontap.models.cluster_space_block_storage_medias API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.cluster_space_block_storage_medias`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ClusterSpaceBlockStorageMediasSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ClusterSpaceBlockStorageMedias object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `available GET POST PATCH`

    Available space

  `efficiency GET POST PATCH`

    The efficiency field of the cluster_space_block_storage_medias.

  `size GET POST PATCH`

    Total space

  `type GET POST PATCH`

    The type of media being used

    Valid choices:

    - hdd
    - hybrid
    - lun
    - ssd
    - vmdisk
  `used GET POST PATCH`

    Used space